@@ -157,8 +157,8 @@ class RFBServer(object):
             return
         modifiers = []
         keyval = 0
-        keycode = source.keyboard_config.get_keycode(0, keyname, pressed, modifiers)
-        log("rfb keycode(%s)=%s", keyname, keycode)
+        keycode, group = source.keyboard_config.get_keycode(0, keyname, pressed, modifiers, 0)
+        log("rfb keycode(%s)=%s, %s", keyname, keycode, group)
         if keycode:
             is_mod = source.keyboard_config.is_modifier(keycode)
             self._handle_key(wid, bool(pressed), keyname, keyval, keycode, modifiers, is_mod, True)
